/**************************************************************************//**
*   @file   ad5254.h
*   @brief  Header file of AD5254 Driver for NIOS processor.
*   @author DBogdan (dragos.bogdan@analog.com)
*
*******************************************************************************
* Copyright 2011(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: 0
******************************************************************************/
#ifndef _AD5254_H_
#define _AD5254_H_
#ifdef AD5254_GLOBALS
	#define AD5254_EXT extern volatile
#else
	#define AD5254_EXT volatile
#endif

/*****************************************************************************/
/* Include Files                                                             */
/*****************************************************************************/
#include "adi.h"
#if (USE_AD5254 == 1)

/*****************************************************************************/
/* AD5254                                                                    */
/*****************************************************************************/
#define AD5254_ADDRESS		0x2C
#define AD5254_NOP			0x80
#define AD5254_1STEPUP		0xD0
#define AD5254_1STEPDOWN	0xA8
#define AD5254_6DBUP		0xC0
#define AD5254_6DBDOWN		0x98
#define AD5254_STORE		0x90
#define AD5254_RESTORE		0x88
#define AD5254_1STEPUPALL	0xD8
#define AD5254_1STEPDOWNALL	0xB0
#define AD5254_6DBUPALL		0xC8
#define AD5254_6DBDOWNALL	0xA0
#define AD5254_RESETALL		0xB8
#define AD5254_TOLR1INT		0x3A
#define AD5254_TOLR1DEC		0x3B
#define AD5254_TOLR3INT		0x3E
#define AD5254_TOLR3DEC		0x3F
#define AD5254_RDAC1ADDRESS	0x01
#define AD5254_RDAC3ADDRESS	0x03
#define AD5254_TOLR0INT		0x38
#define AD5254_TOLR0DEC		0x39
#define AD5254_TOLR2INT		0x3C
#define AD5254_TOLR2DEC		0x3D
#define AD5254_RDAC0ADDRESS	0x00
#define AD5254_RDAC2ADDRESS	0x02

/*****************************************************************************/
/* GPIO                                                                      */
/*****************************************************************************/
#define GPIO_WP	(1<<2)	// WP Pin.

/*****************************************************************************/
/* Monitored variables declarations                                          */
/*****************************************************************************/
AD5254_EXT uCProbeDataUnion AD5254_data[68];	// Used to store the values for uC-Probe communication.
#endif //(USE_AD5254 == 1)

/****************************************************************************/
/* Functions Prototypes                                                     */
/****************************************************************************/
int AD5254_Init(void); 				// Initializes the communication with the device.
int AD5254_UpdateParameters(void); 	// Updates the device's monitored and controlled parameters.
#endif /* AD5254_H_ */
